FabIO Viewer — FabIO 0.2.2 documentation

### Navigation

- index
- modules |
- next |
- previous |
- FabIO 0.2.2 documentation »

# FabIO Viewer

FabIO Viewer is a simple diffraction image viewer based on matplotlib and PyQt4.

    $ fabio_viewer --help
    usage: fabio_viewer img1 img2 ... imgn

    FabIO_viewer is a portable diffraction images viewer/converter: * Written in
    Python, it combines the functionalities of the I/O library fabIO with a user
    friendly Qt4 GUI. * Image converter is also a light viewer based on the
    visualization tool provided by the module matplotlib.

    positional arguments:
      images

    optional arguments:
      -h, --help     show this help message and exit
      -V, --version  Print version & quit

    Based on FabIO version 0.2.2

### Navigation

- index
- modules |
- next |
- previous |
- FabIO 0.2.2 documentation »